@@ -2,11 +2,11 @@
 # https://wiki.archlinux.org/index.php/Perl_Policy#Binaries_and_scripts
 # Added /usr/bin/*_perl dirs for scripts
 
-[ -d /usr/bin/site_perl ] && PATH=$PATH:/usr/bin/site_perl
+[ -d /usr/bin/site_perl ] && append_path '/usr/bin/site_perl'
 
-[ -d /usr/bin/vendor_perl ] && PATH=$PATH:/usr/bin/vendor_perl
+[ -d /usr/bin/vendor_perl ] && append_path '/usr/bin/vendor_perl'
 
-[ -d /usr/bin/core_perl ] && PATH=$PATH:/usr/bin/core_perl
+[ -d /usr/bin/core_perl ] && append_path '/usr/bin/core_perl'
 
 export PATH
 
